{***************************************************************************}
{ TAdvStringGrid Checker component for Addict Spell Checker v3.0            }
{ for Delphi 3.0,4.0,5.0,6.0 & C++Builder 3.0,4.0,5.0                       }
{ version 1.93 - rel. July 2001                                             }
{                                                                           }
{ written by TMS Software                                                   }
{            copyright  1996-2001                                          }
{            Email : info@tmssoftware.com                                   }
{            Web : http://www.tmssoftware.com                               }
{                                                                           }
{ The source code is given as is. The author is not responsible             }
{ for any possible damage done due to the use of this code.                 }
{ The component can be freely used in any application. The complete         }
{ source code remains property of the author and may not be distributed,    }
{ published, given or sold in any form as such. No parts of the source      }
{ code can be included in any other component or application without        }
{ written authorization of the author.                                      }
{***************************************************************************}

unit AsgAddictCheck;

interface

uses
     AsgCheck, Classes, AdvUtil,
     ad3ThesaurusBase, ad3Thesaurus, ad3SpellBase, ad3Spell, ad3StringParser,
     ad3ParserBase, ad3ParseEngine, ad4Live;

type
     TAddictCheck = class (TAdvStringGridCheck)
     private
          FAddictSpell: TAddictSpell;
          FShowDialog: Boolean;
     protected
          procedure Notification (AComponent: TComponent; AOperation: TOperation); override;
     public
          function MarkError (ACol, ARow: Integer; s: string): string; override;
          function Correct (ACol, ARow: Integer; s: string): string; override;
          procedure StartCheck; override;
          procedure StopCheck; override;
     published
          property AddictSpell: TAddictSpell read FAddictSpell write FAddictSpell;
          property ShowDialog: Boolean read FShowDialog write FShowDialog;
     end;

implementation

{ TAddictCheck }

function TAddictCheck.Correct (ACol, ARow: Integer; s: string): string;
var
     FStringParser: TStringParser;
     Word, Corr, Repl: string;

begin
     Result := s;
     Corr := '';

     if not Assigned (FAddictSpell) then
          Exit;

     if FShowDialog then
     begin
          FAddictSpell.CheckString (s);
          Result := s;
          Exit;
     end;

     FStringParser := TStringParser.Create;
     FStringParser.Initialize (@S);

     FAddictSpell.ParsingEngine.Initialize (FStringParser, CheckType_All);

     Word := FAddictSpell.ParsingEngine.NextWord (FStringParser);

     while Word <> '' do
     begin
          Corr := '';
          if not FAddictSpell.CheckWord (Self, Word, Corr) then
          begin
               if (Corr <> '') then
                    Result := ReplaceOnce (Result, Corr, Repl)
               else
                    Result := HiLight (Result, Word, 'e', False);
          end;
          Word := FAddictSpell.ParsingEngine.NextWord (FStringParser);
     end;

     FStringParser.Free;
end;

function TAddictCheck.MarkError (ACol, ARow: Integer; s: string): string;
var
     FStringParser: TStringParser;
     Word, Corr, CorrUnused: string;

begin
     Result := s;
     Corr := s;

     if not Assigned (FAddictSpell) then
          Exit;

     FStringParser := TStringParser.Create;
     FStringParser.Initialize (@S);

     FAddictSpell.ParsingEngine.Initialize (FStringParser, CheckType_All);

     Word := FAddictSpell.ParsingEngine.NextWord (FStringParser);
     while Word <> '' do
     begin
          if not FAddictSpell.CheckWord (Self, Word, CorrUnused) then
               Corr := HiLight (Corr, Word, 'e', False);
          Word := FAddictSpell.ParsingEngine.NextWord (FStringParser);
     end;

     FStringParser.Free;

     Result := Corr;
end;

procedure TAddictCheck.Notification (AComponent: TComponent;
     AOperation: TOperation);
begin
     if (AOperation = opRemove) and (AComponent = FAddictSpell) then
          FAddictSpell := nil;
     inherited;
end;

procedure TAddictCheck.StartCheck;
begin
     if Assigned (FAddictSpell) then
          FAddictSpell.StartSequenceCheck;
end;

procedure TAddictCheck.StopCheck;
begin
     if Assigned (FAddictSpell) then
          FAddictSpell.StopSequenceCheck;
end;

end.

